@@ -7,7 +7,7 @@ use Class::Utils qw(set_params);
 use Error::Pure qw(err);
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -62,6 +62,10 @@ sub query_item {
 	if ($query_string =~ m/^P\d+$/ms) {
 		return $self->_query_property($item, $query_string);
 
+	# Alias.
+	} elsif ($query_string =~ m/^alias:?([\w\-]+)?$/ms) {
+		return $self->_query_text($item, $1, 'aliases');
+
 	# Label.
 	} elsif ($query_string =~ m/^label:?([\w\-]+)?$/ms) {
 		return $self->_query_text($item, $1, 'labels');
@@ -250,6 +254,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
